@@ -64,9 +64,11 @@ char** cmatrix(int nsam, int len);
 void locate(int n, double beg, double len, double *ptr);
 void getpars(int argc, char *argv[], int *phowmany);
 void free_char_2D_AP(char **list, int nsam);
-void free_pars();
+//WCC void free_pars();
+void free_pars(void);
 void argcheck(int arg, int argc, char *argv[]);
-void usage();
+//WCC void usage();
+void usage(void);
 void addtoelist(struct devent *pt, struct devent *elist);
 void free_eventlist(struct devent *pt, int npop);
 void make_gametes(int nsam, int mfreq, struct node *ptree, double tt, int newsites, int ns, char **list);
